*********************
*** preliminaries ***
*********************

clear 
set more 1

*ssc install ebalance
*ssc install cem
*ssc install estout

cd "~/replication"

***Balance Program
***Ensures that Panel is balanced across years

capture program drop balance
program define balance
	args comp sr yr1 yr2 yr3 yr4
	
	capture drop _miss* 
	capture drop __miss*  
	capture drop __MISS* 
	capture drop balanced_panel
	
	sort anid
	gen __miss = 0 
foreach x in `yr1' `yr2' `yr3' `yr4' {
	if "`x'"!=""{
	replace __miss = 1 if (missing(_voted) | missing(`comp') | `sr'==0) & year==`x'
	}
}
bysort anid (year): egen __MISSING = total(__miss),

gen balanced_panel = .

foreach x in `yr1' `yr2' `yr3' `yr4' {
	if "`x'"!=""{
	replace balanced_panel = 1 if __MISSING==0 & year==`x'
	}
}
capture drop _miss*
capture drop __miss*  
capture drop __MISS*
end
*****

*****
*Import and prepare data for analysis

*Merge in District  (time-varying) characteristics

use "dta/district_level_0814", clear
keep st_abbrev district year hh_med_inc hh_mean_inc pct_nh* pct_hispanic inc house_topticket
rename (st_abbrev district) (state_name _cd_)

foreach var of varlist hh_med_inc hh_mean_inc pct_nh* pct_hispanic inc house_topticket{

rename `var' cd_`var'
}

compress

tempfile dist_characteristics

save `dist_characteristics', replace

*Import main catalist file

use "dta/catalist_long", clear

merge m:1 state_name _cd_ year using `dist_characteristics'
drop if _merge==2
drop _merge

*Construct PVI Variable
gen _pvi=substr(pvi,3,2) if substr(pvi,1,1)=="D"
replace _pvi="-"+substr(pvi,3,2) if substr(pvi,1,1)=="R"
replace _pvi="0" if pvi=="EVEN"
destring _pvi, replace

gen abs_pvi = -1*abs(_pvi)

*Construct Cook Report Variable
gen cook = (inlist(rating_num,2,3,4,5))
replace cook = . if rating_num==.

*Construct ex post closeness variable
replace dv = dv*100
gen abs_vote_margin = -1*abs(50-dv)

*Generate covariates

gen female = (ca_gender=="F")
replace female = . if ca_gender== "" | ca_gender=="U"

gen black = (ca_race=="B")
replace black = . if ca_race==""|ca_race=="U"

gen hispanic = (ca_race=="H")
replace hispanic = . if ca_race=="" | ca_race=="U"

gen asian = (ca_race=="A")
replace asian = . if ca_race=="" | ca_race=="U"

*age
*based on age in november of 2015 (electiondayage)
gen age = ca_electiondayage -1 if year==2014
replace age=ca_electiondayage- 3 if year==2012
replace age = ca_electiondayage - 5 if year==2010
replace age= ca_electiondayage-7 if year==2008

gen age_65up = age>=65
replace age_65up = . if age==.

gen registered_dem = ca_partyaffiliation=="DEM"
replace registered_dem =. if ca_partyaffiliation == "UNK" | ca_partyaffiliation==""

gen registered_rep = ca_partyaffiliation=="REP"
replace registered_rep =. if ca_partyaffiliation == "UNK" | ca_partyaffiliation==""

*Education score represents the probability that 
*an individual has a college education or more
gen education = sy_educscore*100

*Generate additional District Level Covariates

*dem incumbent
gen cd_dem_inc = cd_inc == 1
replace cd_dem_inc = . if cd_inc==.

*rep incumbent
gen cd_rep_inc = cd_inc==0
replace cd_rep_inc = . if cd_rep_inc ==.

*log household median income
gen cd_log_hh_med_inc = log(cd_hh_med_inc)


*** code to identify majority-minority states
gen maj_min_st=0 if !missing(state_name)
replace maj_min_st=1 if inlist(state_name,"AL","AZ","CA","FL","GA","HI","IL","LA","MD") | ///
						inlist(state_name,"MI","MO","MS","NC","NJ","NM","NY","OH","PA") | ///
						inlist(state_name,"SC","TN","TX","VA")
						
gen maj_min_nhw_st=0 if !missing(state_name)
replace maj_min_nhw_st=1 if inlist(state_name,"AL","AZ","CA","FL","GA","HI","IL","LA","MA") | ///
							inlist(state_name,"MD","MI","MO","MS","NC","NJ","NM","NV","NY") | ///
							inlist(state_name,"OH","PA","SC","TN","TX","VA","WA","WI")

*Generate state year fixed effects, as well as indicators for other levels of geography
egen _st_yr_n=group(_state_ year)
egen _state_n = group(_state_)
egen _cd_n = group(_state_ _cd_)
egen _precinct_n = group(_state_ ge_fips di_uniqueprecinctcode)
egen _censusbg_n = group(_state_ ge_fips di_countyfips)

*Create CD clusters

bysort anid (year): gen _cd_pre_post = string(_cd_[1]) + "_" + string(_cd_[3]) + "_" + state_name
egen _cd_pre_post_n = group(_cd_pre_post)

fvset base 1 _st_yr_n


*Set to panel data
xtset, clear
xtset anid year

*Construct sample restrictions

*Least Strict: Requires that for time periods under consideration the individual resided in the same state, did not move addresses, did not die, and that elections always were contested and between at least one dem and one republican
gen sr1 = (sr_same_state==1 & sr_notmover==1 & sr_notdead==1 &  uncontested==0 & twoDs_or_twoRs==0)

*Moderately Strict: Adds additional Restriction that they were always over 18
gen sr2 = (sr1==1 & sr_over18==1)
gen sr2_unc = (sr_same_state==1 & sr_notmover==1 & sr_notdead==1 & twoDs_or_twoRs==0 & sr_over18==1)

*Most Strict: We also require that they were registered for the full time period under consideration
gen sr3 = (sr2==1 & sr_alwaysreg==1)

*label for sample restrictions
*Ultimately use Sample Restriction 2 in paper
label var sr1 "Sample Restriction 1:  individual resided in the same state, did not move addresses, did not die, and that elections always were contested and between at least one dem and one republican"
label var sr2 "Sample Restriction 2: SR1 + age always 18+"
label var sr2_unc "Sample Restriction 2b: Same as SR2 but include uncontesteds"
label var sr3 "Sample Restriction 2: SR2 + always registered"

*********************************************
*** variable labels for regression tables ***
*********************************************
label var abs_vote_margin "Ex Post Competitiveness"
label var cook "Cook (toss-ups and leans)"
label var abs_pvi "PVI Competitiveness"
label var age "Age"
label var age_65up "Age 65+"
label var female "Female"
label var black "Non-Hispanic Black"
label var asian "Non-Hispanic Asian"
label var hispanic "Hispanic"
label var education "BA or Higher (\%, Estimated)"
label var _voted "Turnout"         
label var cd_hh_med_inc "Household Median Inc. (CD)"
label var cd_hh_mean_inc "Household Mean Inc. (CD)"
label var cd_log_hh_med_inc "log(Household Median Inc. (CD))"
label var cd_pct_nh_white "Pct. White (CD)"
label var cd_pct_nh_black "Pct. Black (CD)"
label var cd_pct_nh_amindian "Pct. Native American (CD)"
label var cd_pct_nh_hawaiian "Pct. Hawaiin (CD)"
label var cd_pct_nh_asian "Pct. Asian (CD)"
label var cd_pct_nh_other "Pct. Other (CD)"
label var cd_pct_nh_multi "Pct. Multi-Racial (CD)"
label var cd_pct_hispanic "Pct. Hispanic (CD)"
label var cd_inc "Incumbent (CD)"
label var cd_rep_inc "Republican Incumbent (CD)"
label var cd_dem_inc "Democratic Incumbent (CD)"
label var cd_house_topticket "Top of Ticket Race"

label define topticket_lbl 0 "Not Top of Ticket" 1 "Top of Ticket" 

label values cd_house_topticket topticket_lbl

tempfile analysis_file

save `analysis_file', replace

*Prepare data for generating histogram illustrating competitiveness change
keep if sr2 & _voted!=.
keep anid year abs_vote_margin abs_pvi _state_

reshape wide abs_vote_margin abs_pvi, i(anid _state_) j(year)

*lower numbers mean more competitive
gen diff_vote_margin_08_12 = abs_vote_margin2012-abs_vote_margin2008
gen diff_vote_margin_10_14 = abs_vote_margin2014-abs_vote_margin2010
gen diff_vote_margin_10_12 = abs_vote_margin2012-abs_vote_margin2010


gen diff_pvi_08_12 = abs_pvi2012-abs_pvi2008
gen diff_pvi_10_14 = abs_pvi2014-abs_pvi2010
gen diff_pvi_10_12 = abs_pvi2012-abs_pvi2010

***FIG3***
***FIGA2***
***FIGA3***
***FIGA4***
***FIGA5***
***FIGA6***

saveold "dta/user_created_dta/panel_comp_histogram.dta", version(12) replace


*Construct indicator for balanced samples

use `analysis_file', clear

*foreach sr in "sr1" "sr2" "sr3"{
foreach sr in "sr2" "sr2_unc"{

foreach closeness in "abs_pvi" "abs_vote_margin" {

balance `closeness' `sr' 2008 2012
rename balanced_panel bp_`closeness'_`sr'_08_12

balance `closeness' `sr' 2008 2010
rename balanced_panel bp_`closeness'_`sr'_08_10

balance `closeness' `sr' 2010 2014
rename balanced_panel bp_`closeness'_`sr'_10_14

balance `closeness' `sr'  2010 2012
rename balanced_panel bp_`closeness'_`sr'_10_12

balance `closeness' `sr' 2008 2010 2012 2014
rename balanced_panel bp_`closeness'_`sr'__all

}

}

compress

*save main file used for individual level analysis

save "dta/user_created_dta/analysis_file", replace


*********************************
**ANALYSIS SECTION **************
*********************************

*Cross Section Regressions of Turnout on CLoseness
set more off
*Define specifications
local spec1 
local spec2  i._state_n 
local spec3 `spec2' female age_65up education hispanic black asian
local spec4  i._cd_n female age_65up education hispanic black asian

*Define sample restrictions
*local srestrict1 "Least Restrictive Sample"
local srestrict2 "Moderately Restrictive Sample"
*local srestrict3 "Most Restrictive Sample"

*Loop for cross sectional regressions
*Also keep track of whether we are using fixed effects, etc.

***FIGA8***

*************************************************************************************************
**Tables for Individual Cross Section Regressions (Figures Made from These Tables) **************
*************************************************************************************************

forvalues yr = 2008(2)2014{

	local sr = 2

	foreach restriction of varlist sr2 {

		local cp = 1

			foreach comp of varlist abs_pvi abs_vote_margin{

				forvalues n=1(1)3{

					eststo: reg _voted `comp' `spec`n'' if `restriction' & year==`yr', cluster(_cd_n)
					if `n'==2 | `n'==3{
						estadd local stfe "Yes"
					}
					else{
						estadd local stfe "No"
					}

				}

*Output tables to tex and csv

				foreach ftype in "tex" "csv"{

					esttab using "tables/ind_cs_`yr'_sr`sr'_cp`cp'.`ftype'", drop( *_state_n _cons) nostar ar2 se label compress nonotes ///
					noobs sfmt(%14.3gc) scalars("N Observations" "stfe State FEs") ///
					addnotes("Standard errors, clustered at the CD level, are in parentheses."  "The sample is comprised of contested general elections with a D and R candidate." ///
					"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
					title("Cross-Section Individual Regressions of Turnout on Competitiveness: `yr' \label{main`yr'`sr'`cp'}") nomtitles replace
				}
				estimates clear
				local cp = `cp' +2
			}
			local sr = `sr' +1
		}
	}


************************************************************************
**Tables for Panel Data Regressions                       **************
************************************************************************

set more off
use "dta/user_created_dta/analysis_file", clear

*Define specifications and sample restrictions
local specb1 
local specb2 female age_65up education black hispanic asian 

*local srestrict1 "Least Restrictive Sample"
local srestrict2 "Moderately Restrictive Sample"
*local srestrict3 "Most Restrictive Sample"

local distspec1 cd_log_hh_med_inc
local distspec2 cd_pct_nh_black cd_pct_hispanic cd_pct_nh_asian 
local distspec3 cd_rep_inc cd_dem_inc
local distspec4 `distspec1' `distspec2' `distspec3' 


*Loop through regressions for panel data, fe

local k = 1

foreach var of varlist bp_* {

	foreach comp in "abs_pvi" "abs_vote_margin" {

		if strpos("`var'","`comp'")>0 & strpos("`var'","unc")==0{
			local out = "`var'"

			*Create local macro to track and label which years we are using
			if strpos("`var'","08_12"){
				local year "2008 \& 2012"
			} 
			else if strpos("`var'","08_10"){
				local year "2008 \& 2010"
			}
			else if strpos("`var'","10_12"){
				local year "2010 \& 2012"
			}
			else if strpos("`var'","10_14"){
				local year "2010 \& 2014"
			}
			else{
				local year "2008 -- 2014"
			}

			*Keep track of sample restriction imposed
			local sr = substr("`var'",strpos("`var'","sr")+2,1)

			*MAIN SPECIFICATIONS OF PANEL DATA REGRESSIONS
			eststo: reg _voted `comp' i._st_yr_n `specb1' if `var'==1, cluster(_cd_pre_post_n)
			estadd local styrfe "Yes"
			estadd local ife "No"
			estadd local ctrl "No"

			eststo: reg _voted `comp' i._st_yr_n `specb2' if `var'==1, cluster(_cd_pre_post_n)
			estadd local styrfe "Yes"
			estadd local ife "No"
			estadd local ctrl "Yes"

			eststo: xtreg _voted `comp' i._st_yr_n if `var'==1, fe cluster(_cd_pre_post_n)
			estadd local styrfe "Yes"
			estadd local ife "Yes"
			estadd local ctrl "No"

			*Output to tables
			***FIG5***
			
			foreach ftype in "tex" "csv"{
				esttab using "tables/`out'.`ftype'", drop( *_st_yr_n age_65up education black hispanic asian female _cons) nostar se label compress nonotes ///
				noobs sfmt(%14.3gc) scalars("N Observations" "styrfe State-Year FEs" "ife Individual FEs" "ctrl Controls") ///
				addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
				"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
				title("Panel Data Individual Regressions of Turnout on Competitiveness: `year' \label{ind-panel-`k'}") nomtitles replace
			}
			estimates clear

			*White districts only
			eststo: reg _voted `comp' i._st_yr_n if `var'==1 & maj_min_nhw_st==0, cluster(_cd_pre_post_n)
			estadd local styrfe "Yes"
			estadd local ife "No"
			estadd local ctrl "No"

			eststo: reg _voted `comp' i._st_yr_n `spec2b' if `var'==1 & maj_min_nhw_st==0, cluster(_cd_pre_post_n)
			estadd local styrfe "Yes"
			estadd local ife "No"
			estadd local ctrl "Yes"

			eststo: xtreg _voted `comp' i._st_yr_n if `var'==1 & maj_min_nhw_st==0, fe cluster(_cd_pre_post_n)
			estadd local styrfe "Yes"
			estadd local ife "Yes"
			estadd local ctrl "No"

			***TABA10***

			foreach ftype in "tex" "csv"{

				esttab using "tables/`var'_maj_min.`ftype'", drop(_cons *_st_yr_n) nostar se label compress nonotes ///
				noobs sfmt(%14.3gc) scalars("N Observations" "styrfe State-Year FEs" "ife Individual FEs" "ctrl Controls") ///
				addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
				"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
				title("Panel Data Individual Regressions of Turnout on Competitiveness (Only States with No Majority Minority Districts): `year' \label{ind-panel-`k'-maj-min}") nomtitles replace
			}
			estimates clear

			if strpos("`var'","08_12")>0 | strpos("`var'","10_14") | strpos("`var'","_all")>0{

				*Time Varying District Covariates
				***FIGA12***
				
				forvalues z=1(1)4{
					eststo: xtreg _voted `comp' `distspec`z'' i._st_yr_n if `var'==1, fe cluster(_cd_pre_post_n)
				}

				foreach ftype in "tex" "csv"{

					esttab using "tables/`var'_tvcov.`ftype'", keep(`comp') indicate("Income Controls = cd_log_hh_med_inc" "Race Controls = cd_pct_nh_black" "Party/Incumbency Controls = cd_rep_inc") nostar se label compress nonotes ///
					addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
					"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
					title("Panel Data Individual Regressions of Turnout on Competitiveness (Including Time Varying District Characteristics): `year' \label{ind-panel-`k'-cov}") nomtitles replace
				}
				estimates clear

			}

		}

		local k = `k' +1

	}
}

*Examine uncontested elections

***TAB4***
***TABA8***

local j = 1
foreach var of varlist bp_*{
	local j = `j' + 1
	if (strpos("`var'","08_12")>0 | strpos("`var'","10_14") | strpos("`var'","_all")>0) & strpos("`var'","unc")>0 & strpos("`var'","abs_pvi")>0{
		xtreg _voted abs_pvi i._st_yr_n if `var'==1, fe cluster(_cd_pre_post_n)
		estimates store unc`j'
	}

	foreach comp in "abs_pvi" "abs_vote_margin"{
		if (strpos("`var'","10_14") | strpos("`var'","_all")>0) & strpos("`var'","unc")==0 & strpos("`var'","`comp'")>0{
			xtreg _voted c.`comp'##i.cd_house_topticket i._st_yr_n if `var'==1, fe cluster(_cd_pre_post_n)
			estimates store int`j'
		}
	}
}

foreach ftype in "tex" "csv"{

	esttab unc* using "tables/uncontested_rcheck.`ftype'", drop( *_st_yr_n _cons ) nostar se label compress nonotes ///
	nonumbers mtitles("2008 \& 2012" "2010 \& 2014" "All Years") ///
	addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses."  "The sample is comprised of contested general elections with a D and R candidate." ///
	"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
	title("Panel Data Individual Regressions of Turnout on Competitiveness (Including Uncontested Races) \label{ind-panel-unc}") replace

	esttab int* using "tables/topticket_rcheck.`ftype'", drop( *_st_yr_n _cons 1.cd_house_topticket) nostar se label compress nonotes ///
	mgroups("PVI Comp." "Vote Margin", pattern(1 0 1 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nonumbers mtitles("2010 \& 2014" "All Years" "2010 \& 2014" "All Years") ///
	addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
	"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness." "Top of Ticket is not reported since it is a linear combination of state-year FEs.") ///
	title("Panel Data Individual Regressions of Turnout on Competitiveness (Including Top of Ticket Indicator) \label{ind-panel-topticket}") nobaselevels replace
}
estimates clear

***FIG4***

**Create output for Parallel trends Figure

gen old_enough = 1 if ca_electiondayage - 13 >=18

gen close = 1 if abs(abs_pvi)<=10
replace close = 0 if abs(abs_pvi)>10 & abs_pvi<.

keep if bp_abs_pvi_sr2__all==1 & old_enough == 1

keep anid year close

reshape wide close, i(anid) j(year)

gen treatment = "Never Competitive" if close2010==0 & close2012==0
replace treatment = "Always Competitive" if close2010==1 & close2012 ==1
replace treatment = "Competitive Pre-Redistricting Only" if close2010==1 &close2012 ==0
replace treatment = "Competitive Post-Redistricting Only" if close2010==0 & close2012==1

drop close*

merge m:1 anid using "dta/voter_history_1996_2014"
drop if _merge==2
drop _merge

drop _voted1996 - _voted2000
reshape long _voted, i(anid) j(year)

collapse (mean) _voted, by(year treatment)

twoway (line _voted year if treatment=="Always Competitive") (line _voted year if treatment=="Never Competitive") (line _voted year if treatment=="Competitive Pre-Redistricting Only") (line _voted year if treatment=="Competitive Post-Redistricting Only") 

saveold "dta/user_created_dta/pre_trends_graphs", replace version(12)


****Alternative Block Fixed Effects Approach (Prep data)

clear all
use "dta/user_created_dta/analysis_file", clear

merge m:1 anid using "dta/voter_history_1996_2014"
drop if _merge==2
drop _merge

**create education deciles

xtile educ_q = education, nq(5)

gen age_group = 1 if age<25
replace age_group = 2 if age>=25 & age < 35
replace age_group = 3 if age>=35 & age < 45
replace age_group = 4 if age>=45 & age < 55
replace age_group = 5 if age>=55 & age < 65
replace age_group = 6 if age >=65

label define age_lbl 1 "18-24" 2 "25-34" 3 "35-44" 4 "45-54" 5 "55-64" 6 "65+"

label values age_group age_lbl

bysort anid (year): gen _cd_n_yr1 = _cd_n[1]

egen block = group(black hispanic asian female educ_q age_group _cd_n_yr1 _voted2008 _voted2010) if year == 2012, missing

bysort anid (year): replace block = block[3] if missing(block) & year ==2014


*sumary stats about blocks
*in text of paper

/*
tempfile temp0
save `temp0', replace

keep if bp_abs_pvi_sr2_10_14 == 1 & year==2014
count
contract block
count

use `temp0', clear
keep if bp_abs_pvi_sr2_08_12 == 1 & year==2012
count
contract block
count

use `temp0', clear
*/

*Final Summary Table...

local k = 1

foreach var of varlist bp_abs_pvi_sr2_08_12 bp_abs_pvi_sr2_10_14 bp_abs_pvi_sr2__all bp_abs_vote_margin_sr2_08_12 bp_abs_vote_margin_sr2_10_14 bp_abs_vote_margin_sr2__all {

	local comp = substr("`var'",4,strpos("`var'","sr2")-5)

	*Create local macro to track and label which years we are using
	if strpos("`var'","08_12"){
		local year = 2012
		local out = "`comp'_`year'"
	} 
	else if strpos("`var'","10_14"){
		local year = 2014 
		local out = "`comp'_`year'"
	}
	else{
		local year = "2012 \& 2014"
		local out = "`comp'_2012_2014"
	}

	*Keep track of sample restriction imposed
	local sr = 2

	*MAIN SPECIFICATIONS OF PANEL DATA REGRESSIONS

	if strpos("`var'","08_12") | strpos("`var'","10_14") {

		xtreg _voted `comp' i._st_yr_n if `var'==1, fe cluster(_cd_pre_post_n)
		estimates store reg`k'a
		estadd local styrfe "Yes"
		estadd local yrfe "No"
		estadd local ife "Yes"
		estadd local bfe "No"

		areg _voted `comp' if `var'==1 & !missing(block), absorb(block) cluster(_cd_pre_post_n)
		estimates store reg`k'b
		estadd local styrfe "No"
		estadd local yrfe "No"
		estadd local ife "No"
		estadd local bfe "Yes"
}
	else{
	
		xtreg _voted `comp' i._st_yr_n if `var'==1, fe cluster(_cd_pre_post_n)
		estimates store reg`k'a
		estadd local styrfe "Yes"
		estadd local yrfe "No"
		estadd local ife "Yes"
		estadd local bfe "No"
	
		areg _voted `comp' i.year if `var'==1 & !missing(block), absorb(block) cluster(_cd_pre_post_n)
		estimates store reg`k'b
		estadd local styrfe "No"
		estadd local yrfe "Yes"
		estadd local ife "No"
		estadd local bfe "Yes"
	}

	local k = `k' + 1

}


label var abs_vote_margin "Ex Post Comp."
label var abs_pvi "PVI Comp."


***TAB1***

*Output to tables
foreach ftype in "tex" "csv"{
	esttab reg3a reg6a reg1a reg4a reg2a reg5a  using "tables/reg_summary_xt.`ftype'", drop( *_st_yr_n _cons) nostar se label compress nonotes ///
	noobs scalars("N Observations" "ife Individual FEs" "styrfe State-Year FEs" )  sfmt(%14.3gc) ///
	addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
	"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
	mgroups("All Years" "Midterms" "Pres." , pattern(1 0  1 0  1  0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles ///
	title("Summary Table of Individual Regressions of Turnout on Competitiveness, Generalized Differences in Differences (Individual FEs) \label{sumtableife}") replace
	
}

***TAB3***

foreach ftype in "tex" "csv"{
	esttab reg3b reg6b reg1b reg4b reg2b reg5b  using "tables/reg_summary_bfe.`ftype'", drop(*year _cons) nostar se label compress nonotes ///
	noobs scalars("N Observations" "bfe Block FEs" "yrfe Year FEs")  sfmt(%14.3gc) ///
	addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
	"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
	mgroups("2012 \& 2014" "Midterm (2014)" "Pres. (2014)" , pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles ///
	title("Summary Table of Individual Regressions of Turnout on Competitiveness, Block Fixed Effects \label{sumtablebfe}") replace  

}

*Additional Robustness check table for main draft
***TAB2***

local k = 1

foreach var of varlist bp_abs_pvi_sr2_10_12 bp_abs_vote_margin_sr2_10_12 bp_abs_vote_margin_sr2_08_10 {

	local comp = substr("`var'",4,strpos("`var'","sr2")-5)

	*Create local macro to track and label which years we are using
	if strpos("`var'","10_12"){
		local year = 2012
		local out = "`comp'_`year'"
	}
	else{
		local year = "2008 \& 2010"
		local out = "`comp'_2008_2010"
	}

	*Keep track of sample restriction imposed
	local sr = 2

	*MAIN SPECIFICATIONS OF PANEL DATA REGRESSIONS

		xtreg _voted `comp' i._st_yr_n if `var'==1, fe cluster(_cd_pre_post_n)
		estimates store reg`k'a
		estadd local styrfe "Yes"
		estadd local ife "Yes"
	
	local k = `k' + 1

}

*Output to tables
foreach ftype in "tex" "csv"{
	esttab reg1a reg2a reg3a using "tables/reg_checks_xt.`ftype'", drop( *_st_yr_n _cons) nostar se label compress nonotes ///
	noobs scalars("N Observations" "ife Individual FEs" "styrfe State-Year FEs" )  sfmt(%14.3gc) ///
	addnotes("SEs clustered by CD pre/post redistricting (Spec. 1 and 2) and pre only (Spec. 3)." "The sample is comprised of contested general elections with a D and R candidate." ///
	"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
	mgroups("2010 \& 2012" "2008 \& 2010" , pattern(1 0  1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) nomtitles ///
	title("Additional Specifications of Individual Regressions of Turnout on Competitiveness, Generalized Differences in Differences (Individual FEs) \label{checktableife}") replace
	
}



********************************************************************
**Matching (Appendix) Analysis & Marginal Voters Analysis **********
********************************************************************


*Binary treatment Analysis
set more off
clear all
use "dta/user_created_dta/analysis_file", clear

*Measure of closeness  = 1 if abs pvi is less than or equal to 10; otherwise 0
gen close_abs_pvi = abs(abs_pvi)<=10
replace close_abs_pvi = . if abs_pvi==.

*Same logic as above, using actual vote margin (i.e., an ex post measure of competition)
gen close_abs_vote_margin = abs(abs_vote_margin)<=10
replace close_abs_vote_margin = . if abs_vote_margin==.

label var close_abs_pvi "PVI Competitive Election (Binary)"
label var close_abs_vote_margin "Ex Post Competitive Election (Binary)"

merge m:1 anid using "dta/voter_history_1996_2014"
drop if _merge==2
drop _merge

*Classify full panel as ever being treated or not (useful for matching later on)
foreach treatment in "close_abs_pvi" "close_abs_vote_margin"{

bysort anid (year): gen `treatment'_10_14 = 0 if `treatment'[2] ==  0 & `treatment'[4]==0
bysort anid (year): replace `treatment'_10_14 = 1 if `treatment'[2] ==  0 & `treatment'[4]==1

bysort anid (year): gen `treatment'_10_12 = 0 if `treatment'[2] ==  0 & `treatment'[3]==0
bysort anid (year): replace `treatment'_10_12 = 1 if `treatment'[2] ==  0 & `treatment'[3]==1

bysort anid (year): gen `treatment'_08_12 = 0 if `treatment'[1] ==  0 & `treatment'[3]==0
bysort anid (year): replace `treatment'_08_12 = 1 if `treatment'[1] ==  0 & `treatment'[3]==1
}

*Modifies variables to apply to full panel 
bysort anid (year): gen age_65upb = age_65up[2]
bysort anid (year): gen _cd_pre = _cd_[1]
fvset base 1 _st_yr_n

*Perform analysis of marginal voters, rich voters, educated voters

*marginals
gen marginal = 1 if (_voted2006 == 1 & _voted2008==0) | (_voted2006 == 0 & _voted2008==1)
replace marginal = 0 if (_voted2006 == 0 & _voted2008==0) | (_voted2006 == 1 & _voted2008==1)

gen old_enough = (ca_electiondayage - 9 >=18 & ca_electiondayage<.)

*educated
xtile educ_quartile = education, nq(4)
gen most_educated = (educ_quartile==4)
drop educ_quartile

*rich
xtile inc_quartile = ce_medianhhincome, nq(4)
gen rich = (inc_quartile==4)
drop inc_quartile

*partisans

gen partisan = (registered_dem==1 | registered_rep==1)

*first time voters
gen first_time_voter = (ca_electiondayage - 9 >=18 & ca_electiondayage -9 < 20)

****Different effect sizes

gen close_abs_pvi_cat = 3 if -abs_pvi <= 10
replace close_abs_pvi_cat = 2 if -abs_pvi>10 & -abs_pvi<=20
replace close_abs_pvi_cat = 1 if -abs_pvi>20 & -abs_pvi<=30
replace close_abs_pvi_cat = 0 if -abs_pvi>30 & -abs_pvi<.

gen close_abs_vote_margin_cat = 3 if -abs_vote_margin<=10
replace close_abs_vote_margin_cat = 2 if -abs_vote_margin>10 & -abs_vote_margin<=20
replace close_abs_vote_margin_cat = 1 if -abs_vote_margin>20 & -abs_vote_margin<=30
replace close_abs_vote_margin_cat = 0 if -abs_vote_margin>30 & -abs_vote_margin<.

label define pvicat_lbl 0 "80/20 ex ante Vote Margin or more" 1 "70/30 to 80/20 ex ante Vote Margin" 2 "60/40 to 70/30 ex ante Vote Margin" 3 "50/50 to 60/40  ex ante Vote Margin"
label define margcat_lbl 0 "80/20 ex post Vote Margin or more" 1 "70/30 to 80/20 ex post Vote Margin" 2 "60/40 to 70/30 ex post Vote Margin" 3 "50/50 to 60/40  ex post Vote Margin"

label values close_abs_pvi_cat pvicat_lbl

label values close_abs_vote_margin_cat margcat_lbl

label var close_abs_pvi_cat "PVI Competitiveness Magnitudes"
label var close_abs_vote_margin_cat "Vote Margin Magnitudes"

tempfile temp_did
save `temp_did', replace


local res1 "marginal==1 & old_enough==1"
local res2 "most_educated==1"
local res3 "rich==1"
local res4 "partisan==1"
local res5 "first_time_voter==1"

forvalues n=1(1)5{
foreach treatment in "abs_pvi" "abs_vote_margin"{

foreach var in "bp_abs_pvi_sr2_10_14" "bp_abs_vote_margin_sr2_10_14" {

local yr = "10_14"

if strpos("`var'","`treatment'")>0{

eststo: xtreg _voted `treatment' i._st_yr_n if `var'==1 & `res`n'', fe cluster(_cd_pre_post_n)

}
}
}
}

***FIG6***
***TABA7***
foreach ftype in "tex" "csv"{
esttab using "tables/marginal_voters.`ftype'", drop( *_st_yr_n _cons) nostar se label compress nonotes nomtitles ///
mgroups("\shortstack{Marginal \\ Voters}" "\shortstack{Top Quartile \\ Educ.}" "\shortstack{Top Quartile \\ Med. HH Inc.}" "\shortstack{Partisans \\ (Reg. D/R)}" "\shortstack{1st-Time \\ Voters}", pattern(1 0 1 0 1 0 1 0 1 0) ///
prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) coeflabels(abs_pvi "\shortstack{PVI \\ Comp.}" abs_vote_margin "\shortstack{Ex Post \\ Comp.}") ///
addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") substitute({table} {sidewaystable}) ///
title("Individual Regressions of Turnout on Competitiveness: Voters on the Margin, Midterm Elections (2010 \& 2014) \label{ind-panel-marg}") replace
}
estimates clear

****Analysis of big changes versus smaller effects

use `temp_did', clear

foreach treatment in "close_abs_pvi" "close_abs_vote_margin"{

foreach var in "bp_abs_pvi_sr2_10_14" "bp_abs_pvi_sr2_08_12" "bp_abs_vote_margin_sr2_10_14" "bp_abs_vote_margin_sr2_08_12" {
use `temp_did', clear

local comp = substr("`treatment'",7,20)

if(strpos("`var'","08_12")){
local yr = "08_12" 
}

if(strpos("`var'","10_14")){
local yr = "10_14"
}

if strpos("`var'","`comp'")>0{
di "`comp' `yr'"

keep if `var'==1 & `treatment'_`yr'!=.
eststo: xtreg _voted i.`treatment'_cat i._st_yr_n, fe cluster(_cd_pre_post_n)
estadd local styrfe "Yes"
estadd local ife "Yes"
}
}
}

foreach ftype in "tex" "csv"{
esttab using "tables/binary_treatment_did_intensity.`ftype'", drop(_cons *_st_yr_n) nostar se label compress nonotes ///
noobs sfmt(%14.3gc) scalars("N Observations" "styrfe State-Year FEs" "ife Individual FEs" ) ///
nonumbers mtitles("2010 \& 2014 PVI" "2008 \& 2012 PVI" "2010 \& 2014 Vote Marg." "2008 \& 2012 Vote Marg.") ///
addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") ///
title("Differing Treatment Intensity for Individual Regressions of Turnout on Competitiveness  \label{ind-panel-intensity}") replace
}
estimates clear

*Perform analysis based on binary treatment
*Classic DID and Matched DID using entropy balancing

use `temp_did', clear

foreach treatment in "close_abs_pvi" "close_abs_vote_margin"{

foreach var in "bp_abs_pvi_sr2_10_14" "bp_abs_pvi_sr2_08_12" "bp_abs_vote_margin_sr2_10_14" "bp_abs_vote_margin_sr2_08_12" {
use `temp_did', clear

local comp = substr("`treatment'",7,20)

if(strpos("`var'","08_12")){
local yr = "08_12" 
}

if(strpos("`var'","10_14")){
local yr = "10_14"
}

if strpos("`var'","`comp'")>0{
di "`comp' `yr'"

keep if `var'==1 & `treatment'_`yr'!=.
eststo: xtreg _voted `treatment' i._st_yr_n, fe cluster(_cd_pre_post_n)
estadd local styrfe "Yes"
estadd local ife "Yes"
estadd local match "No"

*Performs Entropy balancing (matches up to the 2nd moment of each covariate)
*Exact match on state and initial congressional district
gen wt = .
egen g = group(_state_n _cd_pre)
        levels g, local(gr)
        foreach j of local gr {
		di "`j'"
		count if g==`j' & `treatment'_`yr'==0
		local t0 = `r(N)'
		count if g==`j' & `treatment'_`yr'==1
		local t1 = `r(N)'
		qui: tab `treatment'_`yr' if g==`j'
		if `r(r)' ==2 & `t0'/`t1'>=2 {
		qui: ebalance `treatment'_`yr' _voted2006 black##c.age hispanic##c.age female asian black##c.education hispanic##c.education if g==`j' & year<=2010, targets(2) generate(_webal)
		*qui: ebalance `treatment'_`yr' _voted2006 black##c.age hispanic##c.age female asian black##c.education hispanic##c.education black##registered_dem  hispanic##registered_dem if g==`j' & year<=2010, targets(2) generate(_webal)
		replace wt = _webal if wt==.
		}
        }

bysort anid (year): replace wt = wt[1]

eststo: xtreg _voted `treatment' i._st_yr_n [aweight=wt], fe cluster(_cd_pre_post_n)
estadd local styrfe "Yes"
estadd local ife "Yes"
estadd local match "Yes"

***FIGA9***
***FIGA10***
***FIGA11***

**Output data for creating balance plots
tempfile temp mtemp

gen N = 1
foreach item of varlist _voted2006 black hispanic female asian age_65up age education registered_dem{
gen `item'_sd = `item'
}


save `temp', replace
collapse (mean) _voted2006 black hispanic female asian age_65up age education registered_dem (sd) *_sd (count) N [aweight=wt], by(`treatment'_`yr')
gen matched = 1
save `mtemp', replace

use `temp', clear
collapse (mean) _voted2006 black hispanic female asian age_65up age education registered_dem (sd) *_sd (count) N, by(`treatment')
gen matched = 0 
append using `mtemp'
save `mtemp', replace

use `temp', clear
collapse (mean) _voted2006 black hispanic female asian age_65up age education registered_dem (sd) *_sd (count) N, by(`treatment'_`yr')
gen matched = 0
append using `mtemp'
export delimited using "tables/matchbalance_`var'.csv", replace
}
}
}

***TABA6***
foreach ftype in "tex" "csv"{
esttab using "tables/binary_treatment_did.`ftype'", drop(_cons *_st_yr_n) nostar se label compress nonotes ///
noobs sfmt(%14.3gc) scalars("N Observations" "styrfe State-Year FEs" "ife Individual FEs" ) ///
nonumbers mtitles("DID" "DID Matched" "DID" "DID Matched" "DID" "DID Matched" "DID" "DID Matched") ///
mgroups("2010 \& 2014 PVI" "2008 \& 2012 PVI" "2010 \& 2014 Vote Marg." "2008 \& 2012 Vote Marg.", pattern(1 0 1 0 1 0 1 0) ///
prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
coeflabels(close_abs_pvi "\shortstack{PVI Comp. \\ Election (Binary)}" close_abs_vote_margin "\shortstack{Ex Post Comp. \\ Election (Binary)}") ///
addnotes("Standard errors, clustered at the pre/post redistricting CD level, are in parentheses." "The sample is comprised of contested general elections with a D and R candidate." ///
"All elections in Louisiana are excluded from the sample due to their unusual rules." "Due to the scaling of the outcome and explanatory variables, an estimated coefficient of 0.001" "implies a 1 percentage point increase in turnout for a 10-point increase in competitiveness.") substitute({table} {sidewaystable}) ///
title("Canonical Diff-in-Diff Individual Regressions of Turnout on Competitiveness: Binary Indicators for Competitiveness,  \label{ind-panel-did}") replace
}
estimates clear







